/*
**  Copyright (C) Optumi Inc - All rights reserved.
**
**  You may only use this code under license with Optumi Inc and any distribution or modification is strictly prohibited.
**  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
**/
import * as React from 'react';
import { Global } from '../../../Global';
import { Slider } from '../../../core';
import FormatUtils from '../../../utils/FormatUtils';
export class GraphicsComponent extends React.Component {
    constructor() {
        super(...arguments);
        this.render = () => {
            if (Global.shouldLogOnRender)
                console.log('GraphicsComponentRender (' + new Date().getSeconds() + ')');
            var user = Global.user;
            return (React.createElement("div", { style: this.props.style },
                React.createElement(Slider, { getValue: this.getCoresValue, saveValue: this.saveCoresValue, minValue: -1, maxValue: user.machines.absoluteGraphicsMaxCores, label: 'Cores', color: '#ffba7d', showUnit: true }),
                React.createElement(Slider, { getValue: this.getScoreValue, saveValue: this.saveScoreValue, minValue: -1, maxValue: user.machines.absoluteGraphicsMaxScore, label: 'Score', color: '#ffba7d', showUnit: true }),
                React.createElement(Slider, { getValue: this.getFrequencyValue, saveValue: this.saveFrequencyValue, minValue: -1, step: 1000000, maxValue: user.machines.absoluteGraphicsMaxFrequency, label: 'Frequency', color: '#ffba7d', showUnit: true, styledUnit: FormatUtils.styleFrequencyUnit(), styledValue: FormatUtils.styleFrequencyValue(), unstyledValue: FormatUtils.unstyleFrequencyValue() }),
                React.createElement(Slider, { getValue: this.getMemoryValue, saveValue: this.saveMemoryValue, minValue: -1, step: 1048576, maxValue: user.machines.absoluteGraphicsMaxMemory, label: 'Memory', color: '#ffba7d', showUnit: true, styledUnit: FormatUtils.styleCapacityUnit(), styledValue: FormatUtils.styleCapacityValue(), unstyledValue: FormatUtils.unstyleCapacityValue() })));
        };
        this.handleMetadataChange = () => { this.forceUpdate(); };
        // Will be called automatically when the component is mounted
        this.componentDidMount = () => {
            Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
        };
        // Will be called automatically when the component is unmounted
        this.componentWillUnmount = () => {
            Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
        };
        this.shouldComponentUpdate = (nextProps, nextState) => {
            try {
                if (JSON.stringify(this.props) != JSON.stringify(nextProps))
                    return true;
                if (JSON.stringify(this.state) != JSON.stringify(nextState))
                    return true;
                if (Global.shouldLogOnRender)
                    console.log('SuppressedRender');
                return false;
            }
            catch (error) {
                return true;
            }
        };
    }
    getCoresValue() {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        return graphics.cores[1];
    }
    async saveCoresValue(cores) {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        graphics.cores = [-1, cores, -1];
        tracker.setMetadata(optumi);
    }
    getScoreValue() {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        return graphics.score[1];
    }
    async saveScoreValue(score) {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        graphics.score = [-1, score, -1];
        tracker.setMetadata(optumi);
    }
    getFrequencyValue() {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        return graphics.frequency[1];
    }
    async saveFrequencyValue(frequency) {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        graphics.frequency = [-1, frequency, -1];
        tracker.setMetadata(optumi);
    }
    getMemoryValue() {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        return graphics.memory[1];
    }
    async saveMemoryValue(memory) {
        const tracker = Global.metadata;
        const optumi = tracker.getMetadata();
        const graphics = optumi.metadata.graphics;
        graphics.memory = [-1, memory, -1];
        tracker.setMetadata(optumi);
    }
}
